Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Backend ¶
type Backend struct {
// Name represents an unique apiv1.Service name formatted as <namespace>-<name>-<port>
Name string `json:"name"`
Service *apiv1.Service `json:"service,omitempty"`
// Endpoints contains the list of endpoints currently running
Endpoints []Endpoint `json:"endpoints,omitempty"`
}
Backend describes one or more remote server/s (endpoints) associated with a service +k8s:deepcopy-gen=true
type Endpoint ¶
type Endpoint struct {
// Address IP address of the endpoint
Address string `json:"address"`
// Port number of the TCP port
Port string `json:"port"`
// Target returns a reference to the object providing the endpoint
Target *apiv1.ObjectReference `json:"target,omitempty"`
}
Endpoint describes a kubernetes endpoint in a backend +k8s:deepcopy-gen=true
type Ingress ¶
type Ingress struct {
networking.Ingress
ParsedAnnotations *annotations.Ingress
}
Ingress holds the definition of an Ingress plus its annotations
Click to show internal directories.
Click to hide internal directories.